@@ -570,6 +570,8 @@ class BaseConfig():
                                    '* _hashtag_latlng  '
                                    '* _term_latlng  '
                                    '* _emoji_latlng  '
+                                   '* _month_hashtag  '
+                                   '* _month_latlng  '
                                    '* monthofyear  '
                                    '* month  '
                                    '* dayofmonth  '
@@ -584,6 +586,7 @@ class BaseConfig():
                                    '* city  '
                                    '* place  '
                                    '* latlng  '
+                                   '* community  '
                                    '  '
                                    'Bases not included will be skipped. Per '
                                    'default, **no bases** will be considered. '
@@ -632,9 +635,9 @@ class BaseConfig():
                                    'The crypt.salt variable can also be set (temporarily or permanently) in the '
                                    'hll worker database itself. '
                                    '  '
-                                   'Example:'
+                                   'Example:  '
                                    '```sql'
-                                   'ALTER DATABASE hllworkerdb SET crypt.salt = \'CRYPTSALT\';'
+                                   'ALTER DATABASE hllworkerdb SET crypt.salt = \'CRYPTSALT\';  '
                                    '```'
                                    '  '
                                    '  '
